@@ -108,6 +108,9 @@ class _KustoClientBase(abc.ABC):
         if status == 429:
             raise KustoThrottlingError("The request was throttled by the server.", response) from exception
 
+        if status == 401:
+            raise KustoServiceError(f"401. Missing adequate access rights.", response) from exception
+
         if payload:
             message = f"An error occurred while trying to ingest: Status: {status}, Reason: {response.reason}, Text: {response_text}."
             if response_json:
